@@ -104,7 +104,7 @@ perform TicketCreate Operation. This will return the created ticket number.
 
                 PendingTime {       # optional
                     Year   => 2011,
-                    Month  => 12
+                    Month  => 12,
                     Day    => 03,
                     Hour   => 23,
                     Minute => 05,
@@ -138,6 +138,20 @@ perform TicketCreate Operation. This will return the created ticket number.
                 ForceNotificationToUserID       => [1, 2, 3]                   # optional
                 ExcludeNotificationToUserID     => [1, 2, 3]                   # optional
                 ExcludeMuteNotificationToUserID => [1, 2, 3]                   # optional
+                Attachment => [
+                    {
+                        Content     => 'content'                                 # base64 encoded
+                        ContentType => 'some content type'
+                        Filename    => 'some fine name'
+                    },
+                    # ...
+                ],
+                # or:
+                Attachment => {
+                    Content     => 'content'                                 # base64 encoded
+                    ContentType => 'some content type'
+                    Filename    => 'some fine name'
+                },
 
                 # Signing and encryption, only used when ArticleSend is set to 1
                 Sign => {
@@ -180,12 +194,18 @@ perform TicketCreate Operation. This will return the created ticket number.
                     ExcludeMuteNotificationToUserID => [1, 2, 3]                   # optional
                     Attachment => [
                         {
-                            Content     => 'content'                                 # base64 encoded
-                            ContentType => 'some content type'
+                            Content     => 'content',                                # base64 encoded
+                            ContentType => 'some content type',
                             Filename    => 'some fine name'
                         },
                         # ...
                     ],
+                    # or:
+                    Attachment => {
+                        Content     => 'content'                                 # base64 encoded
+                        ContentType => 'some content type'
+                        Filename    => 'some fine name'
+                    },
                 },
                 # ...
             ],
@@ -206,16 +226,16 @@ perform TicketCreate Operation. This will return the created ticket number.
 
             Attachment => [
                 {
-                    Content     => 'content'                                 # base64 encoded
-                    ContentType => 'some content type'
+                    Content     => 'content',                                # base64 encoded
+                    ContentType => 'some content type',
                     Filename    => 'some fine name'
                 },
                 # ...
             ],
             #or
             #Attachment => {
-            #    Content     => 'content'
-            #    ContentType => 'some content type'
+            #    Content     => 'content',
+            #    ContentType => 'some content type',
             #    Filename    => 'some fine name'
             #},
         },
@@ -226,10 +246,10 @@ perform TicketCreate Operation. This will return the created ticket number.
         ErrorMessage    => '',                      # in case of error
         Data            => {                        # result data payload after Operation
             TicketID    => 123,                     # Ticket ID Znuny
-            TicketNumber => 2324454323322           # Ticket number in Znuny
+            TicketNumber => 2324454323322,          # Ticket number in Znuny
             ArticleID   => 43,                      # Article ID in Znuny
             Error => {                              # should not return errors
-                    ErrorCode    => 'Ticket.Create.ErrorCode'
+                    ErrorCode    => 'Ticket.Create.ErrorCode',
                     ErrorMessage => 'Error Description'
             },
 
@@ -261,7 +281,7 @@ perform TicketCreate Operation. This will return the created ticket number.
                     Responsible        => 'some_responsible_login',
                     ResponsibleID      => 123,
                     Age                => 3456,
-                    Created            => '2010-10-27 20:15:00'
+                    Created            => '2010-10-27 20:15:00',
                     CreateBy           => 123,
                     Changed            => '2010-10-27 20:15:15',
                     ChangeBy           => 123,
@@ -1006,6 +1026,9 @@ sub _CheckArticle {
     # check Article->ContentType
     if ( $Article->{ContentType} ) {
 
+        # Internal issue #595: Remove line breaks from content type.
+        $Article->{ContentType} =~ s{\R}{ }g;
+
         $Article->{ContentType} = lc $Article->{ContentType};
 
         # check Charset part
@@ -1245,6 +1268,9 @@ sub _CheckAttachment {
     # check Article->ContentType
     if ( $Attachment->{ContentType} ) {
 
+        # Internal issue #595: Remove line breaks from content type.
+        $Attachment->{ContentType} =~ s{\R}{ }g;
+
         $Attachment->{ContentType} = lc $Attachment->{ContentType};
 
         # check Charset part
@@ -1668,6 +1694,17 @@ sub _TicketCreate {
             $MimeType = $Article->{MimeType};
         }
 
+        # Base-64-decode attachments.
+        if ( IsHashRefWithData( $Article->{Attachment} ) ) {
+            $Article->{Attachment} = [ $Article->{Attachment} ];
+        }
+        ATTACHMENT:
+        for my $Attachment ( @{ $Article->{Attachment} // [] } ) {
+            next ATTACHMENT if !IsStringWithData( $Attachment->{Content} );
+
+            $Attachment->{Content} = MIME::Base64::decode_base64( $Attachment->{Content} );
+        }
+
         my %ArticleParams = (
             NoAgentNotify        => $Article->{NoAgentNotify} || 0,
             TicketID             => $TicketID,
@@ -1693,6 +1730,7 @@ sub _TicketCreate {
                 Subject => $Subject,
                 Body    => $PlainBody,
             },
+            Attachment => $Article->{Attachment} // [],
         );
 
         # create article
@@ -1710,7 +1748,8 @@ sub _TicketCreate {
                         Content => MIME::Base64::decode_base64( $Attachment->{Content} ),
                     };
                 }
-                $ArticleParams{Attachment} = \@NewAttachments;
+
+                push @{ $ArticleParams{Attachment} }, @NewAttachments;
             }
 
             # signing and encryption
