@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2021-2022 Znuny GmbH, https://znuny.org/
+# Copyright (C) 2021 Znuny GmbH, https://znuny.org/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -54,7 +54,7 @@ sub new {
     ];
 
     $Self->{SupportedDynamicFieldTypes} = {
-        WebserviceText        => 1,
+        WebserviceDropdown    => 1,
         WebserviceMultiselect => 1,
     };
 
@@ -78,7 +78,7 @@ Tests given web-service configuration by connecting and querying the web-service
             SearchTerms              => $Param{SearchTerms},
         },
         DynamicFieldName => 'DFName1',      # optional
-        FieldType        => 'WebserviceText',
+        FieldType        => 'WebserviceDropdown',
         UserID           => 1,
         UserType         => 'Agent',                                        # optional 'Agent' or 'Customer'
     );
@@ -340,12 +340,12 @@ Executes search in configured dynamic field web-service.
     my $Results = [
         {
             'Key'  => 'Znuny3',
-            'ID'   => 'Znuny3'
+            'ID'   => 'Znuny3',
             'Name' => 'Znuny3'
         },
         {
             'Key'  => 'Rocks4',
-            'ID'   => 'Rocks4'
+            'ID'   => 'Rocks4',
             'Name' => 'Rocks4'
         }
         # ...
@@ -1307,7 +1307,7 @@ sub _BackendConfigGet {
     if ( !$Self->{SupportedDynamicFieldTypes}->{ $Param{DynamicFieldConfig}->{FieldType} } ) {
         $LogObject->Log(
             Priority => 'error',
-            Message  => "Unsupported dynamic field type $Param{DynamicField}->{FieldType}.",
+            Message  => "Unsupported dynamic field type $Param{DynamicFieldConfig}->{FieldType}.",
         );
         return;
     }
